@@ -1,20 +1,8 @@
-/* This file is part of the KDE project
-   Copyright (C) 2001 Carsten Pfeiffer <pfeiffer@kde.org>
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 2001 Carsten Pfeiffer <pfeiffer@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "historyprovider.h"
@@ -27,7 +15,7 @@ class KParts::HistoryProviderPrivate
 {
 public:
     HistoryProviderPrivate()
-        : q(0)
+        : q(nullptr)
     {
     }
 
@@ -68,7 +56,7 @@ HistoryProvider::~HistoryProvider()
 {
     if (!historyProviderPrivate.isDestroyed() &&
             historyProviderPrivate()->q == this) {
-        historyProviderPrivate()->q = 0;
+        historyProviderPrivate()->q = nullptr;
     }
 }
 
@@ -80,7 +68,7 @@ bool HistoryProvider::contains(const QString &item) const
 void HistoryProvider::insert(const QString &item)
 {
     d->dict.insert(item);
-    emit inserted(item);
+    Q_EMIT inserted(item);
 }
 
 void HistoryProvider::remove(const QString &item)
@@ -91,6 +79,6 @@ void HistoryProvider::remove(const QString &item)
 void HistoryProvider::clear()
 {
     d->dict.clear();
-    emit cleared();
+    Q_EMIT cleared();
 }
 
