@@ -1,36 +1,24 @@
-/* This file is part of the KDE project
-   Copyright (C) 2003 Daniel Molkentin <molkentin@kde.org>
-   Copyright (C) 2003 David Faure <faure@kde.org>
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 2003 Daniel Molkentin <molkentin@kde.org>
+    SPDX-FileCopyrightText: 2003 David Faure <faure@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
- */
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "statusbarextension.h"
 
+#include "kparts_logging.h"
+
 #include "readonlypart.h"
 #include "guiactivateevent.h"
 
-#include <kmainwindow.h>
+#include <KMainWindow>
 
 #include <QPointer>
 #include <QObject>
 #include <QStatusBar>
 
-#include <QDebug>
-
 using namespace KParts;
 
 ///////////////////////////////////////////////////////////////////
@@ -94,6 +82,12 @@ public:
 
 ///////////////////////////////////////////////////////////////////
 
+StatusBarExtension::StatusBarExtension(KParts::Part *parent)
+    : QObject(parent), d(new StatusBarExtensionPrivate(this))
+{
+    parent->installEventFilter(this);
+}
+
 StatusBarExtension::StatusBarExtension(KParts::ReadOnlyPart *parent)
     : QObject(parent), d(new StatusBarExtensionPrivate(this))
 {
@@ -111,8 +105,6 @@ StatusBarExtension::~StatusBarExtension()
             d->m_statusBarItems[i].widget()->deleteLater();
         }
     }
-
-    delete d;
 }
 
 StatusBarExtension *StatusBarExtension::childObject(QObject *obj)
@@ -123,7 +115,7 @@ StatusBarExtension *StatusBarExtension::childObject(QObject *obj)
 bool StatusBarExtension::eventFilter(QObject *watched, QEvent *ev)
 {
     if (!GUIActivateEvent::test(ev) ||
-            !::qobject_cast<KParts::ReadOnlyPart *>(watched)) {
+            !::qobject_cast<KParts::Part *>(watched)) {
         return QObject::eventFilter(watched, ev);
     }
 
@@ -152,7 +144,7 @@ bool StatusBarExtension::eventFilter(QObject *watched, QEvent *ev)
 QStatusBar *StatusBarExtension::statusBar() const
 {
     if (!d->m_statusBar)  {
-        KParts::ReadOnlyPart *part = qobject_cast<KParts::ReadOnlyPart *>(parent());
+        KParts::Part *part = qobject_cast<KParts::Part *>(parent());
         QWidget *w = part ? part->widget() : nullptr;
         KMainWindow *mw = w ? qobject_cast<KMainWindow *>(w->topLevelWidget()) : nullptr;
         if (mw) {
@@ -190,6 +182,5 @@ void StatusBarExtension::removeStatusBarItem(QWidget *widget)
             return;
         }
 
-    qWarning() << "StatusBarExtension::removeStatusBarItem. Widget not found : " << widget;
+    qCWarning(KPARTSLOG) << "StatusBarExtension::removeStatusBarItem. Widget not found :" << widget;
 }
-
